@@ -656,240 +656,4 @@ tendency_diag = function(dt,
 
 }
 
-###################################################################
-###################################################################
-###################################################################
 
-#' Plot a verification map of percentiles
-#'
-#' For each location, the map shows whether the observed value was normal, below, or above. This makes it possible to visually compare to the usual tercile forecsst
-#'
-#' @param dt input data table. This has to contain the observations for the year to plot, as well as for many other years (which are used to calculate the climatological reference).
-#' The data table should have coumns named `lon`, `lat`, `year`, and an observation column, the name of which is passed as value of `o` to the function, see below.
-#' For each level of `lon`, `lat`, and `year`, the table should only contain one row (this is checked by the function).
-#' @param o name of the column containing the observation.
-#' @param yy The year for which to show the verification map. Defaults to the last year available in dt
-#' @param climatology_period which years should the climatology be calculated on? Defaults to all years (except `yy`) in `dt`
-#' @param out_file optional path and file name (including valid filetype, like .pdf or .png) for saving the file. If not provided, the function just shows the plot in the running R session.
-#'
-#' @return a gg object
-#'
-#' @importFrom ggplotify as.ggplot
-#' @importFrom RColorBrewer brewer.pal
-#'
-#' @examples
-#' \donttest{
-#' # takes a few seconds:
-#' ver_map(chirps_monthly[month == 11],yy = 2018)
-#'}
-#' @export
-
-ver_map = function(dt,o = obs_cols(dt),yy = dt[,max(year)],
-                   climatology_period = unique(dt[,year]),
-                   out_file = NULL)
-
-{
-
-  # for devtools::check()
-  N = dummy_var = lon = lat = is_yy = sample_quantile = how_many_ties = NULL
-
-  if(!('sample_quantile' %in% names(dt))) # this allows us to send in a more prepared data table instead, with precalculated sample quantiles.
-  {
-    if(length(intersect( names(dt),o)) == 0)
-    {
-      stop('Please specify which column contains your observation.')
-    }
-
-    o = o[min(which(o %in% names(dt)))]
-
-    # get data in shape
-    dt_temp = copy(dt[year %in% climatology_period])
-    if(!(yy %in% climatology_period))
-    {
-      dt_temp = rbindlist(list(dt_temp,dt[year == yy]))
-    }
-
-    # remove missing gridpoints:
-    dt_temp = dt_temp[!is.na(get(o))]
-
-    # check that there is only one level per coordinate
-    if(dt_temp[,.N] != unique(dt_temp[,.(lon,lat,year)])[,.N])
-    {
-      stop('Your data table seems to have multiple levels (rows) per year, lon, lat.\n
-  Please subselect before. E.g., if your data contains multiple months, you could run ver_map(dt[month == 10]).')
-    }
-
-    # get climatology percentile
-
-    # put yy last, for resolving ties, see below:
-    dt_temp[,is_yy := (year == yy)]
-    setorderv(dt_temp,c('lon','lat',o, 'is_yy')) # in case of ties (equal o), yy is sorted last
-    ny = length(unique(dt_temp[,year]))
-
-    # check whether there are locations for which not every year has data:
-    check_dt = dt_temp[,.N,by = .(lon,lat)][N!=max(N),]
-    if(check_dt[,.N] > 0)
-    {
-      warning(paste0(check_dt[,.N],' locations only have data for some years and have been removed.'))
-      # a bit hacked:
-      locs = check_dt[,.(lon,lat)][,dummy_var := 1]
-      dt_temp = merge(dt_temp,locs,by = c('lon','lat'),all = T)
-      dt_temp = dt_temp[is.na(dummy_var)][,dummy_var := NULL]
-    }
-
-    dt_temp[,sample_quantile := 100 * seq(1/ny,1,length.out = ny), by = c('lon','lat')]
-    # What about ties? Well, if you have ties in your observations, the function outputs the
-    # right limit of the ECDF (since we included is_yy in the ordering).
-    # This is consistent with statistical practice, but not necessary what you want:
-    # E.g. a location where precip always was exactly zero and is also zero in yy
-    # would get a sample quantile of 100%, and would be shown as above normal.
-    # I think in this context you want to resolve the ties as the center of the jump,
-    # i.e. (F(obs) - F_-(obs))/2. So lets do that:
-
-    dt_temp[,how_many_ties := .N, by = c('lon','lat',o)]
-    # jump size is 100% x (how_many_ties)/(.N), where .N is the number of observations for your gridpoint, which is the sample size
-    # for your ECDF-calculation. Not that how_many_ties is probably almost always 1/.N, which is the discretization level of the ECDF.
-    # Since we sorted yy last in case of ties, we need to subtract half a jump:
-    dt_temp = dt_temp[year == yy]
-    dt_temp[how_many_ties > 1,sample_quantile := sample_quantile - 50*(how_many_ties)/ny, by = c('lon','lat')]
-  } else {dt_temp = dt}
-
-
-  # get plot:
-  pp = ggplot_dt(dt_temp,'sample_quantile')
-
-  # fix levels and colors for colorscale:
-  qqs = c(10,20,33,67,80,90)
-
-  my_colors1 <- RColorBrewer::brewer.pal(9, "BrBG")[c(1,2,3)] # a scale with several browns for dry regions, see RColorBrewer::display.brewer.all()
-  my_colors2 = "#B2EBF2" # This is cyan200 for normal, checkout https://www.r-bloggers.com/2018/12/having-bit-of-party-with-material-colour-palette/
-  my_colors3 <- RColorBrewer::brewer.pal(9, "Greens")[c(5,7,9)] # a scale with greens
-
-  my_colors = c(my_colors1,my_colors2,my_colors3)
-
-  # create the scale you want:
-  sc = scale_fill_stepsn(breaks = qqs,colors = my_colors,name = '',guide = guide_colorsteps(even.steps = FALSE))
-  # overwrite scale without returning the usual warning:
-  suppressMessages(eval(parse(text = "pp = pp + sc + theme(legend.position = 'bottom',legend.direction = 'horizontal')")))
-
-  # now the messy part begins: We want the legend to be horizontal and as wide as the plot (!!!)
-  # turns out that's difficult in ggplot. The following solution is inspired by the first answer posted here: (which does not work for scale_fill_stepsn)
-  # https://stackoverflow.com/questions/71073338/set-legend-width-to-be-100-plot-width
-  # It's still missing legend section labels for 'normal', 'above', 'below'. An alternative way to fit the legend might be the second answer in stackexchange,
-  # using ggh4x::force_panelsizes()
-
-
-  gt <- ggplotGrob(pp)
-
-  # Extract legend
-  is_legend <- which(gt$layout$name == "guide-box")
-  legend <- gt$grobs[is_legend][[1]]
-  legend <- legend$grobs[legend$layout$name == "guides"][[1]]
-  # Set widths in guide gtable
-  width <- as.numeric(legend$widths[4]) # save bar width (assumes 'cm' unit)
-  legend$widths[4] <- unit(1, "null") # replace bar width
-
-  # Set width/x of bar/labels/ticks. Assumes everything is 'cm' unit.
-  width2 = max(legend$grobs[[2]]$x) + legend$grobs[[2]]$width#!!!! legend$grobs[[2]]$width is NOT what you're looking for here
-  rescale2 = function(x) unit(as.numeric(x) / as.numeric(width2) , 'npc')
-
-  legend$grobs[[2]]$width <- rescale2(legend$grobs[[2]]$width)
-  legend$grobs[[2]]$x = rescale2(legend$grobs[[2]]$x)
-
-
-  legend$grobs[[3]]$children[[1]]$x <- unit(
-    as.numeric(legend$grobs[[3]]$children[[1]]$x) / width, "npc"
-  )
-  #legend$grobs[[5]]$x0 <- unit(as.numeric(legend$grobs[[5]]$x0) / width, "npc")
-  #legend$grobs[[5]]$x1 <- unit(as.numeric(legend$grobs[[5]]$x1) / width, "npc")
-
-  # Replace legend
-  gt$grobs[[is_legend]] <- legend
-
-  # Draw new plot
-  grid::grid.newpage()
-  grid::grid.draw(gt)
-  pp = ggplotify::as.ggplot(gt)
-
-  if(!is.null(out_file))
-  {
-    ggsave(pp,filename = out_file)
-  }
-  return(pp)
-}
-
-#' Plot a verification map of percentiles based on precomputed CHIRPS quantiles.
-#'
-#' The quantiles should be computed and saved by the function \code{chirps_ver_map_quantiles}.
-#'
-#' @param yy,mm The year and month for which to show the verification map. Defaults to the month 60 days ago (in order to avoid using preliminary data).
-#' @param version which CHIRPS version to use.
-#' @param resolution Spatial resolution, 'high' or 'low'
-#' @param ... passed on to ver_map.
-#'
-#' @return A gg object
-#'
-#' @importFrom ggplotify as.ggplot
-#' @importFrom RColorBrewer brewer.pal
-#'
-#' @examples
-#' \donttest{ # takes a while:
-#' if(interactive())
-#' ver_map_chirps(mm = 12,yy = 2022)
-#' }
-#'
-#' @export
-
-ver_map_chirps = function(mm = month(Sys.Date()-60),
-                          yy = year(Sys.Date()-60),
-                          version = 'UCSB',resolution = 'low',...)
-{
-  res = sample_quantile = prec = q0.1 = q0.2 = q0.33 = q0.67 = q0.8 = q0.9 = NULL
-  dt = load_chirps(years = yy,
-                   months = mm,
-                   version = version,
-                   resolution = resolution)
-
-  # get directory where quantiles are stored:
-  quantile_dir = file.path(chirps_dir(),version)
-  if(resolution == 'low') quantile_dir = file.path(quantile_dir,'upscaled')
-  quantile_dir = file.path(quantile_dir,'quantiles')
-
-  fn = list.files(quantile_dir,pattern = 'ver_map_quantiles')
-  # for now exclude the seasonal file:
-  fn = grep(fn, pattern='seasonal', invert=TRUE, value=TRUE)
-
-  if(length(fn)>1) warning(paste0('There are multiple quantile files for verification map in the target directory, I am picking\n',fn[1],'\nThe target directory is ',quantile_dir))
-  fn = fn[1]
-
-  load(file.path(quantile_dir,fn))
-  qdt = res$dt[month == mm]
-
-  dt = merge(dt,qdt,by = c('lon','lat','month'))
-
-
-  levels = c(0.1,0.2,0.33,0.67,0.8,0.9,1)
-  level_diffs = levels[2:7]-levels[1:6]
-  sample_quant = function(prec,q0.1,q0.2,q0.33,q0.67,q0.8,q0.9)
-  {
-    res = rep(0.099,length(prec))# just under 0.1
-    res = res + level_diffs[1]*(prec>=q0.1) +
-      level_diffs[2]*(prec>=q0.2) +
-      level_diffs[3]*(prec>=q0.33) +
-      level_diffs[4]*(prec>=q0.67) +
-      level_diffs[5]*(prec>=q0.8) +
-      level_diffs[6]*(prec>=q0.9)
-    return(res)
-  }
-
-  dt[,sample_quantile:=sample_quant(prec,q0.1,q0.2,q0.33,q0.67,q0.8,q0.9)]
-  dt[,sample_quantile := 100*sample_quantile]
-  dt[sample_quantile == 9.9,sample_quantile:=0]
-
-  begin_year = as.numeric(strsplit(fn,'_')[[1]][4])
-  end_year = as.numeric(strsplit(strsplit(fn,'_')[[1]][6],'\\.')[[1]][1])
-
-  message('plotting verification map for ',yy,'/',mm,'\nClimatology reference is ',begin_year,'-',end_year)
-  vm = ver_map(dt,...) + ggtitle(paste0('     ',mm,'/',yy))
-  return(vm)
-}
